import React, { useState, useEffect } from 'react';
import { Input, Menu, Dropdown, Button, Icon, message, Table, Divider, Tag, Select, Form, Alert } from 'antd';
import { FormattedMessage } from 'umi-plugin-react/locale';
import XForm, { FieldTypes } from '../../../components/XForm';
import router from 'umi/router';
import apis from '../../../services/apis';
import request from '../../../utils/request';
import Wangedit from '../../../components/Wangedit/Wangedit'
import moment from 'moment';


const header = props => {
    const companyId = props.location.query.id
  
    const [ data, setData ] = useState({})
    if(companyId){
      useEffect(() => {
        getCompanyData(companyId);
      },[])
    
      // 查询列表
      const getCompanyData = (companyId) => {
        request({
            ...apis.company.get,
            urlData: { id: companyId }
        }).then((data) => {
          setData(data)
        }).catch((err) => {
          message.error(err.msg || err.message)
        })
      }
    }else{
      //第一次进入就创建新的企业
      useEffect(() => {
        addCompanyData();
      },[])

      // 查询列表
      const addCompanyData = () => {
        request({
            ...apis.company.add,
        }).then((data) => {
          setData(data)
        }).catch((err) => {
          message.error(err.msg || err.message)
        })
      }
    }
  
    const fields = [
      {
        label: '已自动生成企业编号',
        name: 'companyCode',
        value: data.companyCode,
        render: <span>{data.companyCode}</span>
      },    
      {
        label: '已生成法大大客户编号',
        name: 'fadadaCode',
        value: data.fadadaCode,
        render: <span>{data.fadadaCode}</span>
      },
      {
        label: '请选择企业管理员身份',
        name: 'companyManagerType',
        value: data.companyManagerType,
        render: <Select style={{ width: '180px' }} placeholder="请选择企业管理员身份">
                  <Select.Option value="legal">法人</Select.Option>
                  <Select.Option value="agent">代理人</Select.Option>
                </Select>,
        rules: [
          { required: true, message: '请选择企业管理员身份' },
        ],
      },
    ]
  
     
    const handleSubmit = (values) => {
      if(data.companyId){
          request({ ...apis.company.update, urlData: { id: data.companyId }, data: { ...values }}).then((data) => {
            console.log(data,"dadadasdadasdasdasdasda")
            message.info("提交成功，请完成认证信息！")
            window.open(data.certifiedAddress);
            cancelPage();
          }).catch((err) => {
            message.error(err.msg || err.message)
          })
        }
    }
  
    const cancelPage = () => {
      router.push({
        pathname: '/eContract/company/list',
      });
    }
  
    return (
      <XForm onSubmit={handleSubmit} onCancel={cancelPage} fields={fields}></XForm>
    )
  }
  
  const WrappedNormalLoginForm = Form.create({ name: 'header' })(header);
  export default WrappedNormalLoginForm